Documentation
¶
Index ¶
- func NewDocument() document.Document
- type Document
- func (e *Document) Close() error
- func (d *Document) Export(uri string) error
- func (e *Document) GetMetadata() (document.Metadata, error)
- func (e Document) GetSheets() ([]string, error)
- func (e *Document) Open(ctx context.Context, reader io.Reader) error
- func (e *Document) ReadContent() (string, error)
- func (e *Document) Replace(replacements map[string]string) error
- func (e *Document) Save(ctx context.Context, writer io.Writer) error
- func (e *Document) Search(keywords []string) ([]document.SearchResult, error)
- func (d *Document) SetContext(ctx context.Context)
- func (d *Document) SetExportFunc(fn func(doc document.Document, uri string) error)
- func (e *Document) SetMetadata(metadata document.Metadata) error
- func (d *Document) SetNamedRange(name, ref string) error
- func (d *Document) SetPassword(password string) error
- func (d *Document) Sheet(name string) (document.Sheet, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewDocument ¶
NewDocument creates a new instance of an Excel document processor.
Types ¶
type Document ¶
type Document struct {
// contains filtered or unexported fields
}
Document implements the document.Document and document.Spreadsheet interfaces. It uses composition to delegate logic to specialized smaller units.
func (*Document) GetMetadata ¶
func (*Document) ReadContent ¶
ReadContent returns the text content of the document.
func (*Document) Search ¶
func (e *Document) Search(keywords []string) ([]document.SearchResult, error)
Search finds keywords in the document.
func (*Document) SetContext ¶
func (*Document) SetExportFunc ¶
func (*Document) SetMetadata ¶
func (*Document) SetNamedRange ¶
func (*Document) SetPassword ¶
Source Files
¶
Click to show internal directories.
Click to hide internal directories.